Fix sample 11_texture_driver for hip-clang (#1370)

이 커밋은 다음에 포함됨:
Yaxun (Sam) Liu
2019-08-28 21:03:20 -04:00
커밋한 사람 Maneesh Gupta
부모 19a9b15306
커밋 793b18c0b1
+6 -1
파일 보기
@@ -21,7 +21,12 @@ THE SOFTWARE.
*/
#include "hip/hip_runtime.h"
extern texture<float, 2, hipReadModeElementType> tex;
#if __HIP__
__hip_pinned_shadow__
#else
extern
#endif
texture<float, 2, hipReadModeElementType> tex;
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;